#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const dot = require("dot-prop");
const meow = require("meow");
const opn = require("opn");
const path = require("path");
const readPkgUp = require("read-pkg-up");
const update_notifier_1 = require("update-notifier");
const logger_1 = require("./logger");
const pkg = require("../package.json");
new update_notifier_1.UpdateNotifier({ pkg }).notify();
const generator_1 = require("./generator");
const server_1 = require("./server");
const exportPage_1 = require("./repository/exportPage");
const cli = meow(`
  Usage:
    $ rocu dirname

  Options:
    --out-dir, -d   Output directory
    --dev, -D       Start development server
    --port, -p      Set port for development server
    --open, -o      Open development server in default browser
`, {
    flags: {
        dev: {
            alias: "D",
            type: "boolean",
        },
        open: {
            alias: "o",
            type: "boolean",
        },
        outDir: {
            alias: "d",
            type: "string",
        },
        port: {
            alias: "p",
            type: "string",
        },
    },
});
const [localDirname = process.cwd()] = cli.input;
const userPkg = readPkgUp.sync({ cwd: localDirname }) || {};
const localOpts = {
    ...dot.get(userPkg, "pkg.rocu"),
    ...cli.flags,
    outDir: path.join(process.cwd(), cli.flags.outDir || ""),
};
logger_1.notifyLog("rocu");
const main = async () => {
    if (localOpts.dev) {
        logger_1.notifyLog("starting dev server");
        server_1.server(localDirname, localOpts)
            .then((srv) => {
            const address = srv.address();
            let url;
            if (typeof address === "string") {
                logger_1.notifyLog(`listening on ${address}`);
                url = address;
            }
            else {
                const { port } = address;
                logger_1.notifyLog(`listening on port: ${port}`);
                url = `http://localhost:${port}`;
            }
            if (localOpts.open) {
                opn(url);
            }
        })
            .catch((err) => {
            logger_1.notifyLog("error", err);
            process.exit(1);
        });
    }
    else {
        const pages = await generator_1.generateStaticPages(localDirname, localOpts);
        if (pages) {
            await exportPage_1.exportPages(pages, localOpts);
        }
    }
};
main();
